@@ -297,8 +297,8 @@ class Client(commandServer, encrypt, Desktop):
         if not uid is None:
             # mount by uid
             p = process(mountCmd, "-t", "cifs", "-o",
-                "cache=%s,domain=%s,vers=%s,user=%s,uid=%d,gid=%d,noperm%s" % (
-                    cache_method, domain, cifs_mount_vers,
+                "cache=%s,domain=%s,user=%s,uid=%d,gid=%d,noperm%s" % (
+                    cache_method, domain,
                     userName, uid, gid, addon),
                 "//%s/%s" % (host, res), rpath,
                 envdict={"PASSWD": userPwd}, stderr=STDOUT)
@@ -306,9 +306,13 @@ class Client(commandServer, encrypt, Desktop):
         else:
             if cmpVersion(self.clVars.Get('cl_cifsutils_ver'), "6.9_rc73") >= 0:
                 addon += ",forcemandatorylock"
+            if rpath in ("unix", "remote_profile"):
+                versopt = ",vers=%s" % cl_cifs_mount_vers
+            else:
+                versopt = ""
             p = process(mountCmd, "-t", "cifs", "-o",
-                "cache=%s,domain=%s,vers=%s,user=%s%s" % (cache_method,
-                    domain, cifs_mount_vers, userName, addon),
+                "cache=%s,domain=%s%s,user=%s%s" % (cache_method,
+                    domain, versopt, userName, addon),
                 "//%s/%s" % (host, res), rpath,
                 envdict={"PASSWD": userPwd}, stderr=STDOUT)
             return p.success()
